Crate smelter_job_manager

Crate smelter_job_manager 

Manage and run jobs for Smelter

Structs

Job
A job in the system.
JobManager
The JobManager holds state and behavior that is shared between multiple jobs.
JobStageResultReceiver
Receive the results of finished tasks for a stage.
JobStageTaskSender
A channel that can send new tasks into a job stage. This type can be cheaply Cloned to use it from multiple places. Say, consuming finished tasks from the stage and adding new jobs to it concurrently from different places. Drop this object or call JobStageTaskSender::finish to signify that no more tasks will be added to the stage.
LogSender
A wrapper around StatusCollector that only sends log messages
SchedulerBehavior
Customization for the behavior of the job scheduler
SerializedWorkerFailure
A stringified error copied from a worker’s output.
StageError
An error that occurred in a job stage
StatusCollector
Collects status messages into a buffer which can be drained on command
StatusSender
A channel that can be used to send status updates from the job manager
StatusUpdateCustomFormatOptions
Verbosity levels for printing status fields
StatusUpdateDataDisplayCustom
A formatter for a StatusUpdateData with custom levels of Verbosity for each field
StatusUpdateItem
A task status update
StatusUpdateItemCustomFormat
A formatter for a StatusUpdateItem with custom levels of Verbosity for each field in the StatusUpdateData
StatusUpdateSpawnedData
Information about a spawned task
StatusUpdateSuccessData
Information about a successful task
SubtaskId
The ID for a subtask, which uniquely identifies it within a [Job].
TaskDefWithOutput
A task definition, along with the output that resulted from running it.
TaskError
An error that occurred in a subtask

Enums

SlowTaskBehavior
When to rerun tasks that may be stalled.
StatusUpdateData
Types of status updates
TaskErrorKind
An error indicating that a task failed in some way.
Verbosity
Verbosity levels for printing status fields

Traits

SpawnedTask
A trait representing a spawned task in the system. Task spawners should return a structure that implements this trait.
SubTask
A definition of a subtask.