Manage and run jobs for Smelter
Structs
- Job
- A job in the system.
- JobManager
- The JobManager holds state and behavior that is shared between multiple jobs.
- JobStage
Result Receiver - Receive the results of finished tasks for a stage.
- JobStage
Task Sender - A channel that can send new tasks into a job stage. This type can be cheaply Cloned to use it from multiple places. Say, consuming finished tasks from the stage and adding new jobs to it concurrently from different places. Drop this object or call JobStageTaskSender::finish to signify that no more tasks will be added to the stage.
- LogSender
- A wrapper around StatusCollector that only sends log messages
- Scheduler
Behavior - Customization for the behavior of the job scheduler
- Serialized
Worker Failure - A stringified error copied from a worker’s output.
- Stage
Error - An error that occurred in a job stage
- Status
Collector - Collects status messages into a buffer which can be drained on command
- Status
Sender - A channel that can be used to send status updates from the job manager
- Status
Update Custom Format Options - Verbosity levels for printing status fields
- Status
Update Data Display Custom - A formatter for a StatusUpdateData with custom levels of Verbosity for each field
- Status
Update Item - A task status update
- Status
Update Item Custom Format - A formatter for a StatusUpdateItem with custom levels of Verbosity for each field in the StatusUpdateData
- Status
Update Spawned Data - Information about a spawned task
- Status
Update Success Data - Information about a successful task
- Subtask
Id - The ID for a subtask, which uniquely identifies it within a [Job].
- Task
DefWith Output - A task definition, along with the output that resulted from running it.
- Task
Error - An error that occurred in a subtask
Enums
- Slow
Task Behavior - When to rerun tasks that may be stalled.
- Status
Update Data - Types of status updates
- Task
Error Kind - An error indicating that a task failed in some way.
- Verbosity
- Verbosity levels for printing status fields
Traits
- Spawned
Task - A trait representing a spawned task in the system. Task spawners should return a structure that implements this trait.
- SubTask
- A definition of a subtask.